<?php

/**
 * @file
 * Helper functions for the Important Information module.
 * 
 * Use module_load_include('inc', 'important_information', 'important_information')
 * to use these functions within another module.
 * 
 * @ingroup important_information
 */


/**
 * Get important information settings.
 */
function _important_information_get_settings() {
  $iiBody = variable_get('important_information__body', array('value' => '', 'format' => NULL));
  return array(
    'title' => variable_get('important_information__title', 'Important Information'),
    'body' => $iiBody['value'],
    'position' => variable_get('important_information__position', 'right'),
    'mobile_position' => variable_get('important_information__mobile_position', 'top'),
    'mobile_breakpoint' => variable_get('important_information__mobile_breakpoint', '768px'),
    'size' => variable_get('important_information__size', '300px'),
    'mobile_size' => variable_get('important_information__mobile_size', '300px'),
    'spacing' => variable_get('important_information__spacing', '10'),
    'enable_dismiss' => variable_get('important_information__enable_dismiss', 0),
    'top_background_color' => variable_get('important_information__top_background_color', 'white'),
    'body_background_color' => variable_get('important_information__body_background_color', 'white'),
    'border_color' => variable_get('important_information__border_color', '#ccc'),
    'border_style' => variable_get('important_information__border_style', 'solid'),
    'border_width' => variable_get('important_information__border_width', '1'),
    'headings_color' => variable_get('important_information__headings_color', '#0282a5'),
    'headings_font_family' => variable_get('important_information__headings_font_family', 'Sans Serif'),
    'headings_main_font_size' => variable_get('important_information__headings_main_font_size', '20px'),
    'headings_secondary_font_size' => variable_get('important_information__headings_secondary_font_size', '18px'),
    'body_font_color' => variable_get('important_information__body_font_color', '#000000'),
    'body_font_family' => variable_get('important_information__body_font_family', 'Sans Serif'),
    'body_font_size' => variable_get('important_information__body_font_size', '16px'),
  );
}

/**
 * Generate custom CSS.
 */
function _important_information_css($settings) {
  // Variables.
  $section_class = '.block-important-information .important-information';
  $body_class = "body.has-important-information.{$settings['position']}";
  // Mixins.
  $border_style = _important_information_border_css($settings);
  $headings_styles = _important_information_headings_css($settings, $section_class);
  $block_body_styles = _important_information_block_body_css($settings, $section_class);
  $color_styles = _important_information_color_css($settings, $section_class);
  // Positioning.
  $positioning_styles = _important_information_positioning_css($settings, $body_class, $section_class);
  $mobile_positioning_styles = _important_information_mobile_positioning_css($settings, $body_class, $section_class);
  // Spacing.
  $spacing_styles = _important_information_spacing_css($settings, $section_class);
  // CSS.
$css = <<<EOT
  $headings_styles
  $section_class { $border_style }
  $spacing_styles
  $block_body_styles
  $color_styles
  $positioning_styles
  $mobile_positioning_styles
EOT;
  return $css;
}

/**
 * Generate custom borders CSS.
 */
function _important_information_border_css($settings) {
  $output = "";
  if ($settings['border_width'] != "" && $settings['border_color'] != "") {
    $output = "border: {$settings['border_width']}px {$settings['border_style']} {$settings['border_color']}";
  }
  return $output;
}

/**
 * Generate custom spacing CSS.
 */
function _important_information_spacing_css($settings, $section_class) {
  $output = "";
  if ($settings['spacing'] != "") {
    $output = "{$section_class} > h1 { padding: {$settings['spacing']}px; }";
    $output .= "{$section_class} .information-body { padding: 0 {$settings['spacing']}px {$settings['spacing']}px; }";
  }
  return $output;
}

/**
 * Generate custom block body CSS.
 */
function _important_information_color_css($settings, $section_class) {
  $output = "";
  if ($settings['top_background_color'] != "") {
    $output = "$section_class .information-head { background-color: {$settings['top_background_color']}; }";
  }
  if ($settings['body_background_color'] != "") {
    $output .= "$section_class .information-body { background-color: {$settings['body_background_color']}; }";
  }
  return $output;
}

/**
 * Generate custom block body CSS.
 */
function _important_information_block_body_css($settings, $section_class) {
  $block_body_class = "$section_class .information-body";
  $block_body_styles = [];
  $output = "";
  if ($settings['body_font_color'] != "") {
    $block_body_styles['color'] = $settings['body_font_color'];
  }
  if ($settings['body_font_family'] != "") {
    $block_body_styles['font-family'] = $settings['body_font_family'];
  }
  if ($settings['body_font_size'] != "") {
    $block_body_styles['font-size'] = $settings['body_font_size'];
  }
  if (count($block_body_styles) > 0) {
    $block_body_styles = _important_information_rules_to_string($block_body_styles);
    $output = "$block_body_class { $block_body_styles }";
  }
  return $output;
}

/**
 * Generate custom headings CSS.
 */
function _important_information_headings_css($settings, $section_class) {
  $title_styles = [];
  $output = "";
  if ($settings['headings_color'] != "") {
    $title_styles['color'] = $settings['headings_color'];
  }
  if ($settings['headings_font_family'] != "") {
    $title_styles['font-family'] = $settings['headings_font_family'];
  }
  $main_title_style = _important_information_rules_to_string($title_styles + ['font-size' => $settings['headings_main_font_size']]);  
  if ($main_title_style != "") {
    $output .= "$section_class h1 { $main_title_style }";
  }
  $secondary_title_style = _important_information_rules_to_string($title_styles + ['font-size' => $settings['headings_secondary_font_size']]);
  if ($secondary_title_style != "") {
    $output .= "$section_class h2 { $secondary_title_style }";
  }
  return $output;
}

/**
 * Generate custom positioning CSS.
 */
function _important_information_positioning_css($settings, $body_class, $section_class) {
  if ($settings['size'] == "") {
    return "";
  }
  // Positioning.
  $position_class = "$section_class.{$settings['position']}";
  $position_style = "";
  $body_margin_styles = "";
  $button_position_styles = "";
  switch ($settings['position']) {
    case 'top':
      $position_style = "height: {$settings['size']};";
      $body_margin_styles = "$body_class > #page-wrapper { margin-top: {$settings['size']}; }";
      $body_margin_styles .= "$body_class > #overlay-container { height: calc(100% - {$settings['size']});top: {$settings['size']}; }";
      break;
    case 'bottom':
      $position_style = "height: {$settings['size']};";
      $body_margin_styles = "$body_class > #page-wrapper { margin-bottom: {$settings['size']}; }";
      $body_margin_styles .= "$body_class > #overlay-container { height: calc(100% - {$settings['size']}); }";
      $button_position_styles = "$body_class .important-information > .dismiss { bottom: calc({$settings['size']} - 25px);top: auto; }";
      $button_position_styles .= "$body_class #block-important-information-important-information .contextual-links-wrapper { bottom: calc({$settings['size']} - 20px);top: auto; }";
      break;
    case 'right':
      $body_margin_styles = "$body_class { margin-right: {$settings['size']}; }";
      $body_margin_styles .= "$body_class #toolbar { right: {$settings['size']}; }";
      $body_margin_styles .= "$body_class > #overlay-container { width: calc(100% - {$settings['size']}); }";
      $position_style = "width: {$settings['size']};";
      break;
    case 'left':
      $body_margin_styles = "$body_class { margin-left: {$settings['size']}; }";
      $body_margin_styles .= "$body_class #toolbar { left: {$settings['size']}; }";
      $body_margin_styles .= "$body_class > #overlay-container { width: calc(100% - {$settings['size']});left: {$settings['size']}; }";
      $position_style = "width: {$settings['size']};";
      $button_position_styles = "$body_class .important-information > .dismiss { left: calc({$settings['size']} - 40px);right: auto; }";
      $button_position_styles .= "$body_class #block-important-information-important-information .contextual-links-wrapper { left: calc({$settings['size']} - 75px);right: auto; }";
      break;
  }
  return <<<EOT
  $position_class { $position_style }
  $body_margin_styles
  $button_position_styles
EOT;
}

/**
 * Generate custom mobile positioning CSS.
 */
function _important_information_mobile_positioning_css($settings, $body_class, $section_class) {
  if ($settings['mobile_size'] == "") {
    return "";
  }
  // Positioning.
  $mobile_class = "@media (max-width: {$settings['mobile_breakpoint']}) { $body_class.mobile-{$settings['mobile_position']} ";
  $position_class = "$mobile_class $section_class.{$settings['position']}";
  $position_style = "";
  $body_margin_styles = "";
  $button_position_styles = "";
  $mobile_styles = "";
  switch ($settings['mobile_position']) {
    case 'top':
      $position_style = "height: {$settings['mobile_size']}; }";
      $body_margin_styles = "$mobile_class > #page-wrapper { margin-top: {$settings['mobile_size']}; } }";
      $body_margin_styles .= "$mobile_class > #overlay-container { height: calc(100% - {$settings['mobile_size']});top: {$settings['mobile_size']}; width: 100%; } }";
      $body_margin_styles .= "$mobile_class #toolbar { right: 0; left: 0; } }";
      $button_position_styles = "$mobile_class .important-information > .dismiss { bottom: auto;top: auto; } }";
      $button_position_styles .= "$mobile_class #block-important-information-important-information .contextual-links-wrapper { bottom: auto;top: auto; } }";
      $mobile_styles = "$position_class { top: 0; left: 0; width: 100%; bottom: auto; } }";
      break;
    case 'bottom':
      $position_style = "height: {$settings['mobile_size']}; }";
      $body_margin_styles = "$mobile_class > #page-wrapper { margin-bottom: {$settings['mobile_size']}; } }";
      $body_margin_styles .= "$mobile_class > #overlay-container { height: calc(100% - {$settings['mobile_size']}); width: 100%; } }";
      $body_margin_styles .= "$mobile_class #toolbar { right: 0; left: 0; } }";
      $button_position_styles = "$mobile_class .important-information > .dismiss { bottom: calc({$settings['mobile_size']} - 25px);top: auto; } }";
      $button_position_styles .= "$mobile_class #block-important-information-important-information .contextual-links-wrapper { bottom: calc({$settings['mobile_size']} - 20px);top: auto; } }";
      $mobile_styles = "$position_class { bottom: 0; left: 0; width: 100%; top: auto; } }";
      break;
    case 'right':
      $body_margin_styles = "$mobile_class { margin-right: {$settings['mobile_size']}; } }";
      $body_margin_styles .= "$mobile_class #toolbar { right: {$settings['mobile_size']}; } }";
      $body_margin_styles .= "$mobile_class > #overlay-container { width: calc(100% - {$settings['mobile_size']}); } }";
      $position_style = "width: {$settings['mobile_size']}; }";
      $mobile_styles = "$position_class { top: 0; right: 0; height: 100%; } }";
      break;
    case 'left':
      $body_margin_styles = "$mobile_class { margin-left: {$settings['mobile_size']}; } }";
      $body_margin_styles .= "$mobile_class #toolbar { left: {$settings['mobile_size']}; } }";
      $body_margin_styles .= "$mobile_class > #overlay-container { width: calc(100% - {$settings['mobile_size']});left: {$settings['mobile_size']}; } }";
      $position_style = "width: {$settings['mobile_size']}; }";
      $button_position_styles = "$mobile_class .important-information > .dismiss { left: calc({$settings['mobile_size']} - 40px);right: auto; } }";
      $button_position_styles .= "$mobile_class #block-important-information-important-information .contextual-links-wrapper { left: calc({$settings['mobile_size']} - 75px);right: auto; } }";
      $mobile_styles = "$position_class { top: 0; left: 0; height: 100%; } }";
      break;
  }
  return <<<EOT
  $position_class { $position_style }
  $body_margin_styles
  $button_position_styles
  $mobile_styles
EOT;
}

/**
 * Turn an array into a stringified set of CSS properties.
 */
function _important_information_rules_to_string($rules) {
  $output = "";
  foreach ($rules as $key => $rule) {
    if ($rule != "") {
      $output .= "$key: $rule;";
    }
  }
  return $output;
}
